@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Tests for Regression Diagnostics and Specification Tests
 
 Created on Thu Feb 09 13:19:47 2012
@@ -244,6 +243,19 @@ class TestDiagnosticG:
         bp = smsdia.het_breuschpagan(res.resid, res.model.exog)
         compare_to_reference(bp, bptest, decimal=(12, 12))
 
+    def test_het_breusch_pagan_1d_err(self):
+        res = self.res
+        x = np.asarray(res.model.exog)[:, -1]
+        with pytest.raises(ValueError, match="The Breusch-Pagan"):
+            smsdia.het_breuschpagan(res.resid, x)
+        x = np.ones_like(x)
+        with pytest.raises(ValueError, match="The Breusch-Pagan"):
+            smsdia.het_breuschpagan(res.resid, x)
+        x = np.asarray(res.model.exog).copy()
+        x[:, 0] = 0
+        with pytest.raises(ValueError, match="The Breusch-Pagan"):
+            smsdia.het_breuschpagan(res.resid, x)
+
     def test_het_breusch_pagan_nonrobust(self):
         res = self.res
 
@@ -402,14 +414,16 @@ class TestDiagnosticG:
             distr="chi2",
         )
 
-        lb, lbpval, bp, bppval = smsdia.acorr_ljungbox(
-            res.resid, 4, boxpierce=True, return_df=False
+        df = smsdia.acorr_ljungbox(res.resid, 4, boxpierce=True)
+        compare_to_reference(
+            [df.loc[4, "lb_stat"], df.loc[4, "lb_pvalue"]],
+            ljung_box_4,
+            decimal=(12, 12),
         )
         compare_to_reference(
-            [lb[-1], lbpval[-1]], ljung_box_4, decimal=(12, 12)
-        )
-        compare_to_reference(
-            [bp[-1], bppval[-1]], ljung_box_bp_4, decimal=(12, 12)
+            [df.loc[4, "bp_stat"], df.loc[4, "bp_pvalue"]],
+            ljung_box_bp_4,
+            decimal=(12, 12),
         )
 
     def test_acorr_ljung_box_big_default(self):
@@ -427,14 +441,17 @@ class TestDiagnosticG:
             statistic=45.12238537034000, pvalue=0.26638168491464, distr="chi2"
         )
         lags = min(40, res.resid.shape[0] // 2 - 2)
-        lb, lbpval, bp, bppval = smsdia.acorr_ljungbox(
-            res.resid, boxpierce=True, lags=lags, return_df=False
+        df = smsdia.acorr_ljungbox(res.resid, boxpierce=True, lags=lags)
+        idx = df.index.max()
+        compare_to_reference(
+            [df.loc[idx, "lb_stat"], df.loc[idx, "lb_pvalue"]],
+            ljung_box_none,
+            decimal=(12, 12),
         )
         compare_to_reference(
-            [lb[-1], lbpval[-1]], ljung_box_none, decimal=(12, 12)
-        )
-        compare_to_reference(
-            [bp[-1], bppval[-1]], ljung_box_bp_none, decimal=(12, 12)
+            [df.loc[idx, "bp_stat"], df.loc[idx, "bp_pvalue"]],
+            ljung_box_bp_none,
+            decimal=(12, 12),
         )
 
     def test_acorr_ljung_box_small_default(self):
@@ -457,13 +474,6 @@ class TestDiagnosticG:
             parameters=(0,),
             distr="chi2",
         )
-        if isinstance(res.resid, np.ndarray):
-            resid = res.resid[:30]
-        else:
-            resid = res.resid.iloc[:30]
-        lb, lbpval, bp, bppval = smsdia.acorr_ljungbox(
-            resid, boxpierce=True, lags=13, return_df=False
-        )
         if isinstance(res.resid, np.ndarray):
             resid = res.resid[:30]
         else:
@@ -478,10 +488,9 @@ class TestDiagnosticG:
             decimal=(12, 12),
         )
         compare_to_reference(
-            [lb[-1], lbpval[-1]], ljung_box_small, decimal=(12, 12)
-        )
-        compare_to_reference(
-            [bp[-1], bppval[-1]], ljung_box_bp_small, decimal=(12, 12)
+            [df.loc[idx, "bp_stat"], df.loc[idx, "bp_pvalue"]],
+            ljung_box_bp_small,
+            decimal=(12, 12),
         )
 
     def test_acorr_ljung_box_against_r(self, reset_randomstate):
@@ -505,8 +514,8 @@ class TestDiagnosticG:
             [3.8104, 5, 0.577],
             [8.4779, 10, 0.5823],
         ]
-        res_y1 = smsdia.acorr_ljungbox(y1, 10, return_df=True)
-        res_y2 = smsdia.acorr_ljungbox(y2, 10, return_df=True)
+        res_y1 = smsdia.acorr_ljungbox(y1, 10)
+        res_y2 = smsdia.acorr_ljungbox(y2, 10)
         for i, loc in enumerate((1, 5, 10)):
             row = res_y1.loc[loc]
             assert_allclose(
@@ -524,13 +533,11 @@ class TestDiagnosticG:
                 r_results_y2_lb[i][2], row.loc["lb_pvalue"], rtol=1e-3
             )
 
-        res = smsdia.acorr_ljungbox(y2, 10, boxpierce=True, return_df=True)
+        res = smsdia.acorr_ljungbox(y2, 10, boxpierce=True)
         assert_allclose(res.loc[10, "bp_stat"], 7.8935, rtol=1e-3)
         assert_allclose(res.loc[10, "bp_pvalue"], 0.639, rtol=1e-3)
 
-        res = smsdia.acorr_ljungbox(
-            y2, 10, boxpierce=True, return_df=True, model_df=1
-        )
+        res = smsdia.acorr_ljungbox(y2, 10, boxpierce=True, model_df=1)
         assert_allclose(res.loc[10, "bp_pvalue"], 0.5449, rtol=1e-3)
 
     def test_harvey_collier(self):
@@ -1040,7 +1047,7 @@ class TestDiagnosticG:
         infl = oi.OLSInfluence(res)
 
         path = os.path.join(cur_dir, "results", "influence_lsdiag_R.json")
-        with open(path, "r") as fp:
+        with open(path, encoding="utf-8") as fp:
             lsdiag = json.load(fp)
 
         # basic
@@ -1239,7 +1246,7 @@ def test_influence_wrapped():
 
     # this test is slow
     path = os.path.join(cur_dir, "results", "influence_lsdiag_R.json")
-    with open(path, "r") as fp:
+    with open(path, encoding="utf-8") as fp:
         lsdiag = json.load(fp)
 
     c0, c1 = infl.cooks_distance  # TODO: what's c1, it's pvalues? -ss
@@ -1686,24 +1693,34 @@ def test_ljungbox_dof_adj():
     data = sunspots.load_pandas().data["SUNACTIVITY"]
     res = AutoReg(data, 4, old_names=False).fit()
     resid = res.resid
-    res1 = smsdia.acorr_ljungbox(resid, lags=10, return_df=False)
-    res2 = smsdia.acorr_ljungbox(resid, lags=10, model_df=4, return_df=False)
-    assert_allclose(res1[0], res2[0])
-    assert np.all(np.isnan(res2[1][:4]))
-    assert np.all(res2[1][4:] <= res1[1][4:])
+    res1 = smsdia.acorr_ljungbox(resid, lags=10)
+    res2 = smsdia.acorr_ljungbox(resid, lags=10, model_df=4)
+    assert_allclose(res1.iloc[:, 0], res2.iloc[:, 0])
+    assert np.all(np.isnan(res2.iloc[:4, 1]))
+    assert np.all(res2.iloc[4:, 1] <= res1.iloc[4:, 1])
 
 
-def test_ljungbox_auto_lag_selection():
+def test_ljungbox_auto_lag_selection(reset_randomstate):
     data = sunspots.load_pandas().data["SUNACTIVITY"]
     res = AutoReg(data, 4, old_names=False).fit()
     resid = res.resid
-    res1 = smsdia.acorr_ljungbox(resid, return_df=False, auto_lag=True)
-    res2 = smsdia.acorr_ljungbox(
-        resid, model_df=4, return_df=False, auto_lag=True
-    )
-    assert_allclose(res1[0], res2[0])
-    assert np.all(np.isnan(res2[1][:4]))
-    assert np.all(res2[1][4:] <= res1[1][4:])
+    res1 = smsdia.acorr_ljungbox(resid, auto_lag=True)
+    res2 = smsdia.acorr_ljungbox(resid, model_df=4, auto_lag=True)
+    assert_allclose(res1.iloc[:, 0], res2.iloc[:, 0])
+    # TODO: compare selected lags with Stata/ R to confirm
+    # that corect auto_lag is selected
+    assert res1.shape[0] >= 1
+    assert res2.shape[0] >= 1
+    assert np.all(np.isnan(res2.iloc[:4, 1]))
+    assert np.all(res2.iloc[4:, 1] <= res1.iloc[4:, 1])
+
+
+def test_ljungbox_auto_lag_whitenoise(reset_randomstate):
+    data = np.random.randn(1000)  # white noise process
+    res = smsdia.acorr_ljungbox(data, auto_lag=True)
+    # TODO: compare selected lags with Stata/ R to confirm
+    # that correct auto_lag is selected
+    assert res.shape[0] >= 1  # auto lag selected must be at least 1
 
 
 def test_ljungbox_errors_warnings():
@@ -1714,7 +1731,7 @@ def test_ljungbox_errors_warnings():
         smsdia.acorr_ljungbox(data, model_df=-1, period=1)
     with pytest.raises(ValueError, match="period must"):
         smsdia.acorr_ljungbox(data, model_df=-1, period=-2)
-    smsdia.acorr_ljungbox(data, return_df=False)
+    smsdia.acorr_ljungbox(data)
     ret = smsdia.acorr_ljungbox(data, lags=10)
     assert isinstance(ret, pd.DataFrame)
 
@@ -1722,8 +1739,8 @@ def test_ljungbox_errors_warnings():
 def test_ljungbox_period():
     data = sunspots.load_pandas().data["SUNACTIVITY"]
     ar_res = AutoReg(data, 4, old_names=False).fit()
-    res = smsdia.acorr_ljungbox(ar_res.resid, period=13, return_df=True)
-    res2 = smsdia.acorr_ljungbox(ar_res.resid, lags=26, return_df=True)
+    res = smsdia.acorr_ljungbox(ar_res.resid, period=13)
+    res2 = smsdia.acorr_ljungbox(ar_res.resid, lags=26)
     assert_frame_equal(res, res2)
 
 
@@ -1822,7 +1839,7 @@ def test_acorr_lm_smoke(store, ddof, cov, reset_randomstate):
 
 def test_acorr_lm_smoke_no_autolag(reset_randomstate):
     e = np.random.standard_normal(250)
-    smsdia.acorr_lm(e, nlags=6, autolag=None, store=False, ddof=0)
+    smsdia.acorr_lm(e, nlags=6, store=False, ddof=0)
 
 
 @pytest.mark.parametrize("frac", [0.25, 0.5, 0.75])
@@ -1840,7 +1857,7 @@ def test_rainbow_smoke_order_by(frac, order_by, reset_randomstate):
     e = pd.DataFrame(np.random.standard_normal((500, 1)))
     x = pd.DataFrame(
         np.random.standard_normal((500, 3)),
-        columns=["x{0}".format(i) for i in range(3)],
+        columns=[f"x{i}" for i in range(3)],
     )
     y = x @ np.ones((3, 1)) + e
     res = OLS(y, x).fit()
@@ -1852,7 +1869,7 @@ def test_rainbow_smoke_centered(center, reset_randomstate):
     e = pd.DataFrame(np.random.standard_normal((500, 1)))
     x = pd.DataFrame(
         np.random.standard_normal((500, 3)),
-        columns=["x{0}".format(i) for i in range(3)],
+        columns=[f"x{i}" for i in range(3)],
     )
     y = x @ np.ones((3, 1)) + e
     res = OLS(y, x).fit()
@@ -1863,7 +1880,7 @@ def test_rainbow_exception(reset_randomstate):
     e = pd.DataFrame(np.random.standard_normal((500, 1)))
     x = pd.DataFrame(
         np.random.standard_normal((500, 3)),
-        columns=["x{0}".format(i) for i in range(3)],
+        columns=[f"x{i}" for i in range(3)],
     )
     y = x @ np.ones((3, 1)) + e
     res = OLS(y, x).fit()
@@ -1939,3 +1956,43 @@ def test_small_skip(reset_randomstate):
 # M2 + fit(M1)-exp(fit(M2)) < 2.22e-16 ***
 # ---
 # Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
+
+@pytest.mark.smoke
+def test_diagnostics_pandas(reset_randomstate):
+    # GH 8879
+    n = 100
+    df = pd.DataFrame(
+        {
+            "y": np.random.rand(n),
+            "x": np.random.rand(n),
+            "z": np.random.rand(n)}
+    )
+    y, x = df["y"], add_constant(df["x"])
+
+    res = OLS(df["y"], add_constant(df[["x"]])).fit()
+    res_large = OLS(df["y"], add_constant(df[["x", "z"]])).fit()
+    res_other = OLS(df["y"], add_constant(df[["z"]])).fit()
+    smsdia.linear_reset(res_large)
+    smsdia.linear_reset(res_large, test_type="fitted")
+    smsdia.linear_reset(res_large, test_type="exog")
+    smsdia.linear_reset(res_large, test_type="princomp")
+    smsdia.het_goldfeldquandt(y, x)
+    smsdia.het_breuschpagan(res.resid, x)
+    smsdia.het_white(res.resid, x)
+    smsdia.het_arch(res.resid)
+    smsdia.acorr_breusch_godfrey(res)
+    smsdia.acorr_ljungbox(y)
+    smsdia.linear_rainbow(res)
+    smsdia.linear_lm(res.resid, x)
+    smsdia.linear_harvey_collier(res)
+    smsdia.acorr_lm(res.resid)
+    smsdia.breaks_cusumolsresid(res.resid)
+    smsdia.breaks_hansen(res)
+    smsdia.compare_cox(res, res_other)
+    smsdia.compare_encompassing(res, res_other)
+    smsdia.compare_j(res, res_other)
+    smsdia.recursive_olsresiduals(res)
+    smsdia.recursive_olsresiduals(
+        res, order_by=np.arange(y.shape[0] - 1, 0 - 1, -1)
+    )
+    smsdia.spec_white(res.resid, x)
