@@ -11,11 +11,12 @@ practice. OTexts, 2014.
 Author: Terence L van Zyl
 Modified: Kevin Sheppard
 """
+
 from statsmodels.compat.pandas import deprecate_kwarg
 
+from collections.abc import Hashable, Sequence
 import contextlib
 from typing import Any
-from collections.abc import Hashable, Sequence
 import warnings
 
 import numpy as np
@@ -234,9 +235,7 @@ class ExponentialSmoothing(TimeSeriesModel):
             trend = {"additive": "add", "multiplicative": "mul"}[trend]
         self.trend = trend
         self.damped_trend = bool_like(damped_trend, "damped_trend")
-        seasonal = string_like(
-            seasonal, "seasonal", options=options, optional=True
-        )
+        seasonal = string_like(seasonal, "seasonal", options=options, optional=True)
         if seasonal in ["additive", "multiplicative"]:
             seasonal = {"additive": "add", "multiplicative": "mul"}[seasonal]
         self.seasonal = seasonal
@@ -277,12 +276,8 @@ class ExponentialSmoothing(TimeSeriesModel):
             optional=False,
             options=options,
         )
-        self._initial_level = float_like(
-            initial_level, "initial_level", optional=True
-        )
-        self._initial_trend = float_like(
-            initial_trend, "initial_trend", optional=True
-        )
+        self._initial_level = float_like(initial_level, "initial_level", optional=True)
+        self._initial_trend = float_like(initial_trend, "initial_trend", optional=True)
         self._initial_seasonal = array_like(
             initial_seasonal, "initial_seasonal", optional=True
         )
@@ -324,9 +319,7 @@ class ExponentialSmoothing(TimeSeriesModel):
             if ("smoothing" in key or "damp" in key) and (
                 bound[0] < 0.0 or bound[1] > 1.0
             ):
-                raise ValueError(
-                    f"{key} must have a lower bound >= 0.0 and <= 1.0"
-                )
+                raise ValueError(f"{key} must have a lower bound >= 0.0 and <= 1.0")
         return bounds
 
     def _boxcox(self):
@@ -403,9 +396,7 @@ class ExponentialSmoothing(TimeSeriesModel):
                 raise ValueError("smoothing_trend must be <= smoothing_level")
             gamma = values.get("smoothing_seasonal", 0.0)
             if gamma > 1 - alpha:
-                raise ValueError(
-                    "smoothing_seasonal must be <= 1 - smoothing_level"
-                )
+                raise ValueError("smoothing_seasonal must be <= 1 - smoothing_level")
 
         try:
             self._fixed_parameters = values
@@ -504,9 +495,7 @@ class ExponentialSmoothing(TimeSeriesModel):
                 start = self._index.shape[0]
             else:
                 start = self._index[-1] + freq
-        start, end, out_of_sample, _ = self._get_prediction_index(
-            start=start, end=end
-        )
+        start, end, out_of_sample, _ = self._get_prediction_index(start=start, end=end)
         if out_of_sample > 0:
             res = self._predict(h=out_of_sample, **params)
         else:
@@ -532,9 +521,7 @@ class ExponentialSmoothing(TimeSeriesModel):
         return initial_p
 
     @staticmethod
-    def _check_blocked_keywords(
-        d: dict, keys: Sequence[Hashable], name="kwargs"
-    ):
+    def _check_blocked_keywords(d: dict, keys: Sequence[Hashable], name="kwargs"):
         for key in keys:
             if key in d:
                 raise ValueError(f"{name} must not contain '{key}'")
@@ -834,9 +821,7 @@ class ExponentialSmoothing(TimeSeriesModel):
         orig_bounds = self._construct_bounds()
 
         bounds = np.array(orig_bounds[:3], dtype=float)
-        hw_args = HoltWintersArgs(
-            sel.astype(np.int64), params, bounds, y, m, self.nobs
-        )
+        hw_args = HoltWintersArgs(sel.astype(np.int64), params, bounds, y, m, self.nobs)
         params = self._get_starting_values(
             params,
             start_params,
@@ -1064,9 +1049,7 @@ class ExponentialSmoothing(TimeSeriesModel):
         initial_level = float_like(initial_level, "initial_level", True)
         initial_trend = float_like(initial_trend, "initial_trend", True)
         start_params = array_like(start_params, "start_params", optional=True)
-        minimize_kwargs = dict_like(
-            minimize_kwargs, "minimize_kwargs", optional=True
-        )
+        minimize_kwargs = dict_like(minimize_kwargs, "minimize_kwargs", optional=True)
         minimize_kwargs = {} if minimize_kwargs is None else minimize_kwargs
         use_basinhopping = bool_like(
             use_basinhopping, "use_basinhopping", optional=True
@@ -1095,8 +1078,7 @@ class ExponentialSmoothing(TimeSeriesModel):
             )
         if use_boxcox is not None:
             raise ValueError(
-                "use_boxcox was set at model initialization and cannot "
-                "be changed"
+                "use_boxcox was set at model initialization and cannot " "be changed"
             )
         elif self._use_boxcox is None:
             use_boxcox = False
@@ -1139,11 +1121,9 @@ class ExponentialSmoothing(TimeSeriesModel):
         res.y = y
         res.params = start_params
         res.mle_retvals = res.mask = None
-        method = "SLSQP" if method is None else method
+        method = "L-BFGS-B" if method is None else method
         if optimized:
-            res = self._optimize_parameters(
-                res, use_brute, method, minimize_kwargs
-            )
+            res = self._optimize_parameters(res, use_brute, method, minimize_kwargs)
         else:
             l0, b0, s0 = self.initial_values(
                 initial_level=initial_level, initial_trend=initial_trend
@@ -1177,9 +1157,7 @@ class ExponentialSmoothing(TimeSeriesModel):
         hwfit._results.mle_retvals = res.mle_retvals
         return hwfit
 
-    def initial_values(
-        self, initial_level=None, initial_trend=None, force=False
-    ):
+    def initial_values(self, initial_level=None, initial_trend=None, force=False):
         """
         Compute initial values used in the exponential smoothing recursions.
 
@@ -1325,15 +1303,9 @@ class ExponentialSmoothing(TimeSeriesModel):
             if damped
             else np.arange(1, h + 1 + 1)
         )
-        trended = {"mul": np.multiply, "add": np.add, None: lambda l, b: l}[
-            trend
-        ]
-        detrend = {"mul": np.divide, "add": np.subtract, None: lambda l, b: 0}[
-            trend
-        ]
-        dampen = {"mul": np.power, "add": np.multiply, None: lambda b, phi: 0}[
-            trend
-        ]
+        trended = {"mul": np.multiply, "add": np.add, None: lambda l, b: l}[trend]
+        detrend = {"mul": np.divide, "add": np.subtract, None: lambda l, b: 0}[trend]
+        dampen = {"mul": np.power, "add": np.multiply, None: lambda b, phi: 0}[trend]
         nobs = self.nobs
         if seasonal == "mul":
             for i in range(1, nobs + 1):
@@ -1354,9 +1326,7 @@ class ExponentialSmoothing(TimeSeriesModel):
                 b[:nobs] = dampen(b[:nobs], phi)
                 b[nobs:] = dampen(b[nobs], phi_h)
             trend = trended(lvls, b)
-            s[nobs + m - 1 :] = [
-                s[(nobs - 1) + j % m] for j in range(h + 1 + 1)
-            ]
+            s[nobs + m - 1 :] = [s[(nobs - 1) + j % m] for j in range(h + 1 + 1)]
             fitted = trend * s[:-m]
         elif seasonal == "add":
             for i in range(1, nobs + 1):
@@ -1381,9 +1351,7 @@ class ExponentialSmoothing(TimeSeriesModel):
                 b[:nobs] = dampen(b[:nobs], phi)
                 b[nobs:] = dampen(b[nobs], phi_h)
             trend = trended(lvls, b)
-            s[nobs + m - 1 :] = [
-                s[(nobs - 1) + j % m] for j in range(h + 1 + 1)
-            ]
+            s[nobs + m - 1 :] = [s[(nobs - 1) + j % m] for j in range(h + 1 + 1)]
             fitted = trend + s[:-m]
         else:
             for i in range(1, nobs + 1):
